/* Project name:
'     AudioAmp click
' * Copyright:
'     (c) Mikroelektronika, 2016.
' * Revision History:
'     20160523:
'       - mikroC release (AM);
' * Description:
'     AudioAmp click is a mikroBUS add-on board that functions as a mono audio amplifier. 
'     It is driven by a Texas Instruments LM48100Q-Q1 Boomer Mono, 1.3W Audio Power Amplifier IC.
' * Test configuration:
'     MCU:             ATMEGA32
'                      http://www.atmel.com/Images/doc2503.pdf
'     Dev.board:       EasyAVR v7
'                      http://www.mikroe.com/easyavr/
'     Oscillator:      External Clock 8.0000 MHz
'     Ext. Modules:    AudioAmp click
'                      http://www.mikroe.com/store/components/various/
'     SW:              mikroC PRO for AVR
'                      http://www.mikroe.com/mikroc/avr/
' * NOTES:
'       - Place AudioAmp click to the mikroBUS1 socket


/* Pins
 ******************************************************************************/
sbit AA_SCL at PORTA2_bit;
sbit AA_SDA at PORTA3_bit;

/* Variables
 ******************************************************************************/
#define POWER_ON                0x1C
#define VOLUME_1                0x60
#define VOLUME_2                0x80

static char dev_addr = 0xF8;

/* Prototypes
 ******************************************************************************/
void system_init();
void power_on();
void volume( char value );

/* Functions
 ******************************************************************************/
void system_init()
{
    DDRA = 0xFF;

    AA_SDA = 0;
    AA_SCL = 0;
    AA_SDA = 1;
    AA_SCL = 1;
    Delay_ms( 300 );
    AA_SDA = 0;
    AA_SCL = 0;
    Delay_ms( 300 );

    TWI_Init( 100000 );
    Delay_ms( 200 );
}

void power_on()
{
    TWI_Start();
    TWI_Write( dev_addr );
    TWI_Write( POWER_ON );
    TWI_Stop();
}

void volume( char value )
{
    if ( value > 0x1F )
       return;

    TWI_Start();
    TWI_Write( dev_addr );
    TWI_Write( value | VOLUME_1 );
    TWI_Stop();

    TWI_Start();
    TWI_Write( dev_addr );
    TWI_Write( value | VOLUME_2 );
    TWI_Stop();
}

/* Main
 ******************************************************************************/
void main()
{
    system_init();
    power_on();
    volume( 15 );

    while( 1 );
}